@@ -151,9 +151,9 @@ arv_camera_set_region (ArvCamera *camera, int x, int y, int width, int height)
 {
 	g_return_if_fail (ARV_IS_CAMERA (camera));
 
-	if (x > 0)
+	if (x >= 0)
 		arv_device_set_integer_feature_value (camera->priv->device, "OffsetX", x);
-	if (y > 0)
+	if (y >= 0)
 		arv_device_set_integer_feature_value (camera->priv->device, "OffsetY", y);
 	if (width > 0)
 		arv_device_set_integer_feature_value (camera->priv->device, "Width", width);
@@ -460,7 +460,16 @@ arv_camera_set_exposure_time (ArvCamera *camera, double exposure_time_us)
 	if (exposure_time_us <= 0)
 		return;
 
-	arv_device_set_float_feature_value (camera->priv->device, "ExposureTimeAbs", exposure_time_us);
+	switch (camera->priv->vendor) {
+		case ARV_CAMERA_VENDOR_BASLER:
+			arv_device_set_float_feature_value (camera->priv->device, "ExposureTimeBaseAbs", exposure_time_us);
+			arv_device_set_integer_feature_value (camera->priv->device, "ExposureTimeRaw", 1);
+			break;
+		case ARV_CAMERA_VENDOR_PROSILICA:
+		case ARV_CAMERA_VENDOR_UNKNOWN:
+			arv_device_set_float_feature_value (camera->priv->device, "ExposureTimeAbs", exposure_time_us);
+			break;
+	}
 }
 
 /**
@@ -477,6 +486,22 @@ arv_camera_get_exposure_time (ArvCamera *camera)
 	return arv_device_get_float_feature_value (camera->priv->device, "ExposureTimeAbs");
 }
 
+void
+arv_camera_get_exposure_time_bounds (ArvCamera *camera, double *min, double *max)
+{
+	g_return_if_fail (ARV_IS_CAMERA (camera));
+
+	switch (camera->priv->vendor) {
+		case ARV_CAMERA_VENDOR_BASLER:
+			arv_device_get_float_feature_bounds (camera->priv->device, "ExposureTimeBaseAbs", min, max);
+			break;
+		case ARV_CAMERA_VENDOR_PROSILICA:
+		case ARV_CAMERA_VENDOR_UNKNOWN:
+			arv_device_get_float_feature_bounds (camera->priv->device, "ExposureTimeAbs", min, max);
+			break;
+	}
+}
+
 /* Analog control */
 
 /**
@@ -512,6 +537,14 @@ arv_camera_get_gain (ArvCamera *camera)
 	return arv_device_get_integer_feature_value (camera->priv->device, "GainRaw");
 }
 
+void
+arv_camera_get_gain_bounds (ArvCamera *camera, gint64 *min, gint64 *max)
+{
+	g_return_if_fail (ARV_IS_CAMERA (camera));
+
+	arv_device_get_integer_feature_bounds (camera->priv->device, "GainRaw", min, max);
+}
+
 /* Transport layer control */
 
 /**
